@@ -7,31 +7,38 @@
 
 #include "AboutRedirector.h"
 #include "nsNetUtil.h"
-#include "nsIAboutNewTabService.h"
+#include "nsIAppStartup.h"
 #include "nsIChannel.h"
 #include "nsIURI.h"
 #include "nsIProtocolHandler.h"
 #include "nsServiceManagerUtils.h"
+#include "mozilla/Components.h"
 #include "mozilla/StaticPrefs_browser.h"
 #include "mozilla/dom/ContentChild.h"
+#include "mozilla/browser/NimbusFeatures.h"
+
+#define PROFILES_ENABLED_PREF "browser.profiles.enabled"
+#define ABOUT_WELCOME_CHROME_URL \
+  "chrome://browser/content/aboutwelcome/aboutwelcome.html"
+#define ABOUT_HOME_URL "about:home"
+#define BASE_BROWSER_HOME_PAGE_URL "about:mullvad-browser"
 
 namespace mozilla {
 namespace browser {
 
 NS_IMPL_ISUPPORTS(AboutRedirector, nsIAboutModule)
 
-static const uint32_t ACTIVITY_STREAM_FLAGS =
-    nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::ENABLE_INDEXED_DB |
-    nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
-    nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS |
-    nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT;
-
 struct RedirEntry {
   const char* id;
   const char* url;
   uint32_t flags;
 };
 
+static const uint32_t BASE_BROWSER_HOME_PAGE_FLAGS =
+    nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
+    nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
+    nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::IS_SECURE_CHROME_UI;
+
 /*
   Entries which do not have URI_SAFE_FOR_UNTRUSTED_CONTENT will run with chrome
   privileges. This is potentially dangerous. Please use
@@ -78,16 +85,13 @@ static const RedirEntry kRedirMap[] = {
 #endif
     {"policies", "chrome://browser/content/policies/aboutPolicies.html",
      nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::IS_SECURE_CHROME_UI},
-    {"privatebrowsing", "about:blank",
-     nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
-         nsIAboutModule::URI_MUST_LOAD_IN_CHILD | nsIAboutModule::ALLOW_SCRIPT |
-         nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS},
+    {"privatebrowsing", "about:blank", BASE_BROWSER_HOME_PAGE_FLAGS},
     {"profiling",
-     "chrome://devtools/content/performance-new/aboutprofiling/index.xhtml",
+     "chrome://devtools/content/performance-new/aboutprofiling/index.html",
      nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::IS_SECURE_CHROME_UI},
     {"rights", "chrome://global/content/aboutRights.xhtml",
      nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
-         nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::IS_SECURE_CHROME_UI},
+         nsIAboutModule::URI_MUST_LOAD_IN_CHILD},
 #ifndef BASE_BROWSER_VERSION
     {"robots", "chrome://browser/content/aboutRobots.xhtml",
      nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
@@ -96,22 +100,16 @@ static const RedirEntry kRedirMap[] = {
     {"sessionrestore", "chrome://browser/content/aboutSessionRestore.xhtml",
      nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::HIDE_FROM_ABOUTABOUT |
          nsIAboutModule::IS_SECURE_CHROME_UI},
-    // Removed about:shoppingsidebar. tor-browser#42831.
     {"tabcrashed", "chrome://browser/content/aboutTabCrashed.xhtml",
      nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
          nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::HIDE_FROM_ABOUTABOUT},
     {"welcomeback", "chrome://browser/content/aboutWelcomeBack.xhtml",
      nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::HIDE_FROM_ABOUTABOUT |
          nsIAboutModule::IS_SECURE_CHROME_UI},
-    // Actual activity stream URL for home and newtab are set in channel
-    // creation
-    {"home", "about:blank", ACTIVITY_STREAM_FLAGS},
-    {"newtab", "chrome://browser/content/blanktab.html", ACTIVITY_STREAM_FLAGS},
-    {"welcome", "about:blank",
-     nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
-         nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS |
-         nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
-         nsIAboutModule::ALLOW_SCRIPT},
+    {"welcome", "about:blank", BASE_BROWSER_HOME_PAGE_FLAGS},
+    {"home", "about:blank", BASE_BROWSER_HOME_PAGE_FLAGS},
+    {"newtab", "chrome://browser/content/blanktab.html",
+     BASE_BROWSER_HOME_PAGE_FLAGS},
     {"messagepreview",
      "chrome://browser/content/messagepreview/messagepreview.html",
      nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
@@ -153,16 +151,29 @@ static const RedirEntry kRedirMap[] = {
          nsIAboutModule::HIDE_FROM_ABOUTABOUT},
     {"restartrequired", "chrome://browser/content/aboutRestartRequired.xhtml",
      nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::HIDE_FROM_ABOUTABOUT},
+#ifdef MOZ_SELECTABLE_PROFILES
     {"profilemanager", "chrome://browser/content/profiles/profiles.html",
-     nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
-         nsIAboutModule::URI_MUST_LOAD_IN_CHILD | nsIAboutModule::ALLOW_SCRIPT |
-         nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS |
+     nsIAboutModule::ALLOW_SCRIPT | nsIAboutModule::IS_SECURE_CHROME_UI |
          nsIAboutModule::HIDE_FROM_ABOUTABOUT},
+    {"editprofile", "chrome://browser/content/profiles/edit-profile.html",
+     nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
+         nsIAboutModule::IS_SECURE_CHROME_UI | nsIAboutModule::ALLOW_SCRIPT |
+         nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
+         nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS},
+    {"deleteprofile", "chrome://browser/content/profiles/delete-profile.html",
+     nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
+         nsIAboutModule::IS_SECURE_CHROME_UI |
+         nsIAboutModule::URI_MUST_LOAD_IN_CHILD | nsIAboutModule::ALLOW_SCRIPT |
+         nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS},
+    {"newprofile", "chrome://browser/content/profiles/new-profile.html",
+     nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
+         nsIAboutModule::IS_SECURE_CHROME_UI | nsIAboutModule::ALLOW_SCRIPT |
+         nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
+         nsIAboutModule::URI_CAN_LOAD_IN_PRIVILEGEDABOUT_PROCESS},
+#endif
     {"mullvad-browser",
      "chrome://browser/content/mullvad-browser/aboutMullvadBrowser.html",
-     nsIAboutModule::URI_MUST_LOAD_IN_CHILD |
-         nsIAboutModule::URI_SAFE_FOR_UNTRUSTED_CONTENT |
-         nsIAboutModule::IS_SECURE_CHROME_UI},
+     BASE_BROWSER_HOME_PAGE_FLAGS},
 };
 
 static nsAutoCString GetAboutModuleName(nsIURI* aURI) {
@@ -189,22 +200,19 @@ AboutRedirector::NewChannel(nsIURI* aURI, nsILoadInfo* aLoadInfo,
 
   nsAutoCString path = GetAboutModuleName(aURI);
 
-  nsresult rv;
-  nsCOMPtr<nsIIOService> ioService = do_GetIOService(&rv);
-  NS_ENSURE_SUCCESS(rv, rv);
+  if ((path.EqualsASCII("editprofile") || path.EqualsASCII("deleteprofile") ||
+       path.EqualsASCII("newprofile")) &&
+      !mozilla::Preferences::GetBool(PROFILES_ENABLED_PREF, false)) {
+    return NS_ERROR_NOT_AVAILABLE;
+  }
 
-  // If we're accessing about:home in the "privileged about content
-  // process", then we give the nsIAboutNewTabService the responsibility
-  // to return the nsIChannel, since it might be from the about:home
-  // startup cache.
-  if (XRE_IsContentProcess() && path.EqualsLiteral("home")) {
-    auto& remoteType = dom::ContentChild::GetSingleton()->GetRemoteType();
-    if (remoteType == PRIVILEGEDABOUT_REMOTE_TYPE) {
-      nsCOMPtr<nsIAboutNewTabService> aboutNewTabService =
-          do_GetService("@mozilla.org/browser/aboutnewtab-service;1", &rv);
-      NS_ENSURE_SUCCESS(rv, rv);
-
-      return aboutNewTabService->AboutHomeChannel(aURI, aLoadInfo, result);
+  if (path.EqualsASCII("profilemanager") &&
+      !mozilla::Preferences::GetBool(PROFILES_ENABLED_PREF, false)) {
+    bool startingUp;
+    nsCOMPtr<nsIAppStartup> appStartup(
+        mozilla::components::AppStartup::Service());
+    if (NS_FAILED(appStartup->GetStartingUp(&startingUp)) || !startingUp) {
+      return NS_ERROR_NOT_AVAILABLE;
     }
   }
 
@@ -212,25 +220,11 @@ AboutRedirector::NewChannel(nsIURI* aURI, nsILoadInfo* aLoadInfo,
     if (!strcmp(path.get(), redir.id)) {
       nsAutoCString url;
 
-      // Let the aboutNewTabService decide where to redirect for about:home and
-      // enabled about:newtab. Disabled about:newtab page uses fallback.
-      if (path.EqualsLiteral("home") ||
-          (StaticPrefs::browser_newtabpage_enabled() &&
-           path.EqualsLiteral("newtab")) ||
-          path.EqualsLiteral("privatebrowsing")) {
-        nsCOMPtr<nsIAboutNewTabService> aboutNewTabService =
-            do_GetService("@mozilla.org/browser/aboutnewtab-service;1", &rv);
-        NS_ENSURE_SUCCESS(rv, rv);
-        rv = aboutNewTabService->GetDefaultURL(url);
-        NS_ENSURE_SUCCESS(rv, rv);
-      }
-
-      if (path.EqualsLiteral("welcome")) {
-        nsCOMPtr<nsIAboutNewTabService> aboutNewTabService =
-            do_GetService("@mozilla.org/browser/aboutnewtab-service;1", &rv);
-        NS_ENSURE_SUCCESS(rv, rv);
-        rv = aboutNewTabService->GetWelcomeURL(url);
-        NS_ENSURE_SUCCESS(rv, rv);
+      if (path.EqualsLiteral("welcome") || path.EqualsLiteral("home") ||
+          path.EqualsLiteral("privatebrowsing") ||
+          (path.EqualsLiteral("newtab") &&
+           StaticPrefs::browser_newtabpage_enabled())) {
+        url.AssignASCII(BASE_BROWSER_HOME_PAGE_URL);
       }
 
       // fall back to the specified url in the map
@@ -240,7 +234,7 @@ AboutRedirector::NewChannel(nsIURI* aURI, nsILoadInfo* aLoadInfo,
 
       nsCOMPtr<nsIChannel> tempChannel;
       nsCOMPtr<nsIURI> tempURI;
-      rv = NS_NewURI(getter_AddRefs(tempURI), url);
+      nsresult rv = NS_NewURI(getter_AddRefs(tempURI), url);
       NS_ENSURE_SUCCESS(rv, rv);
 
       // If tempURI links to an external URI (i.e. something other than
